package org.xesstandard.extensions;

import java.net.URI;
import java.util.UUID;

import org.xesstandard.model.XesAttribute;
import org.xesstandard.model.XesComponent;
import org.xesstandard.model.attributes.XesIdAttribute;
import org.xesstandard.model.attributes.impl.XesIdAttributeImpl;
import org.xesstandard.model.impl.XesExtensionImpl;

public class XesIdExtension extends XesExtensionImpl {

	public final static String ID = "identity:id";

	private final static XesIdExtension singleton = new XesIdExtension();

	private XesIdExtension() {
		super(true);
		setName("Identity");
		setPrefix("identity");
		try {
			setURI(new URI("http://www.xes-standard.org/identity.xesext"));
		} catch (Exception e) {
			System.err.println(e.getMessage());
		}

		XesAttribute attribute = new XesIdAttributeImpl();
		attribute.setKey(ID);
		addLogAttribute(attribute);
		addTraceAttribute(attribute);
		addEventAttribute(attribute);
		addMetaAttribute(attribute);
		addAlias(attribute, "EN", "Identity");
		addAlias(attribute, "DE", "Identit\u00e4t");
		addAlias(attribute, "FR", "Identit\u00e9");
		addAlias(attribute, "ES", "Identidad");
		addAlias(attribute, "PT", "Identidade");
	}

	/**
	 * @return The single instance of this extension.
	 */
	public static XesIdExtension instance() {
		return singleton;
	}

	private XesIdAttribute setUUID(XesComponent component, String key, UUID value) {
		XesIdAttribute attribute = new XesIdAttributeImpl();
		attribute.setKey(key);
		attribute.setValue(value);
		component.addAttribute(attribute);
		return attribute;
	}
	
	/**
	 * Returns the id of the given component, that is, the value of the
	 * attribute with key "identity:id".
	 * 
	 * @param component
	 *            The given log, trace, event, or attribute.
	 * @return The id of the given component.
	 */
	public UUID getId(XesComponent component) {
		return component.getId(ID);
	}

	/**
	 * Sets the id for the given component, that is, the value of the attribute
	 * with key "identity:id".
	 * 
	 * @param component
	 *            The given log, trace, event, or attribute.
	 * @param value
	 *            The id to set.
	 * @return The attribute containing the id.
	 */
	public XesIdAttribute setId(XesComponent component, UUID value) {
		return setUUID(component, ID, value);
	}
}
