package org.xesstandard.extensions;

import java.net.URI;

import org.xesstandard.model.XesAttribute;
import org.xesstandard.model.XesComponent;
import org.xesstandard.model.XesEvent;
import org.xesstandard.model.attributes.XesStringAttribute;
import org.xesstandard.model.attributes.impl.XesStringAttributeImpl;
import org.xesstandard.model.impl.XesExtensionImpl;

public class XesOrganizationalExtension extends XesExtensionImpl {

	public final static String RESOURCE = "org:resource";
	public final static String ROLE = "org:role";
	public final static String GROUP = "org:group";

	private final static XesOrganizationalExtension singleton = new XesOrganizationalExtension();

	private XesOrganizationalExtension() {
		super(true);
		setName("Organizational");
		setPrefix("org");
		try {
			setURI(new URI("http://www.xes-standard.org/org.xesext"));
		} catch (Exception e) {
			System.err.println(e.getMessage());
		}

		XesAttribute attribute = new XesStringAttributeImpl();
		attribute.setKey(RESOURCE);
		addEventAttribute(attribute);
		addAlias(attribute, "EN", "Resource");
		addAlias(attribute, "DE", "Akteur");
		addAlias(attribute, "FR", "Agent");
		addAlias(attribute, "ES", "Recurso");
		addAlias(attribute, "PT", "Recurso");

		attribute = new XesStringAttributeImpl();
		attribute.setKey(ROLE);
		addEventAttribute(attribute);
		addAlias(attribute, "EN", "Role");
		addAlias(attribute, "DE", "Rolle");
		addAlias(attribute, "FR", "R\u00f4le");
		addAlias(attribute, "ES", "Papel");
		addAlias(attribute, "PT", "Papel");

		attribute = new XesStringAttributeImpl();
		attribute.setKey(GROUP);
		addEventAttribute(attribute);
		addAlias(attribute, "EN", "Group");
		addAlias(attribute, "DE", "Gruppe");
		addAlias(attribute, "FR", "Groupe");
		addAlias(attribute, "ES", "Grupo");
		addAlias(attribute, "PT", "Grupo");
	}

	/**
	 * @return The single instance of this extension.
	 */
	public static XesOrganizationalExtension instance() {
		return singleton;
	}

	private XesStringAttribute setString(XesComponent component, String key, String value) {
		XesStringAttribute attribute = new XesStringAttributeImpl();
		attribute.setKey(key);
		attribute.setValue(value);
		component.addAttribute(attribute);
		return attribute;
	}
	
	/**
	 * Returns the resource associated with the given event, that is, the value
	 * of the attribute with key "org:resource".
	 * 
	 * @param event
	 *            The given event.
	 * @return The resource associated with the given event.
	 */
	public String getResource(XesEvent event) {
		return event.getString(RESOURCE);
	}

	/**
	 * Sets the resource associated with the given event, that is, the value of
	 * the attribute with key "org:resource".
	 * 
	 * @param event
	 *            The given event.
	 * @param value
	 *            The resource to set.
	 * @return The attribute containing the resource.
	 */
	public XesStringAttribute setResource(XesEvent event, String value) {
		return setString(event, RESOURCE, value);
	}

	/**
	 * Returns the role associated with the given event, that is, the value of
	 * the attribute with key "org:role".
	 * 
	 * @param event
	 *            The given event.
	 * @return The role associated with the given event.
	 */
	public String getRole(XesEvent event) {
		return event.getString(ROLE);
	}

	/**
	 * Sets the role associated with the given event, that is, the value of the
	 * attribute with key "org:role".
	 * 
	 * @param event
	 *            The given event.
	 * @param value
	 *            The role to set.
	 * @return The attribute containing the role.
	 */
	public XesStringAttribute setRole(XesEvent event, String value) {
		return setString(event, ROLE, value);
	}

	/**
	 * Returns the group associated with the given event, that is, the value of
	 * the attribute with key "org:group".
	 * 
	 * @param event
	 *            The given event.
	 * @return The group associated with the given event.
	 */
	public String getGroup(XesEvent event) {
		return event.getString(GROUP);
	}

	/**
	 * Sets the group associated with the given event, that is, the value of the
	 * attribute with key "org:group".
	 * 
	 * @param event
	 *            The given event.
	 * @param value
	 *            The group to set.
	 * @return The attribute containing the group.
	 */
	public XesStringAttribute setGroup(XesEvent event, String value) {
		return setString(event, GROUP, value);
	}
}
