package org.xesstandard.extensions;

import java.net.URI;
import java.util.Date;

import org.xesstandard.model.XesAttribute;
import org.xesstandard.model.XesComponent;
import org.xesstandard.model.XesEvent;
import org.xesstandard.model.attributes.XesDateTimeAttribute;
import org.xesstandard.model.attributes.impl.XesDateTimeAttributeImpl;
import org.xesstandard.model.attributes.impl.XesStringAttributeImpl;
import org.xesstandard.model.impl.XesExtensionImpl;

public class XesTimeExtension extends XesExtensionImpl {

	public final static String TIME = "time:timestamp";

	private final static XesTimeExtension singleton = new XesTimeExtension();

	private XesTimeExtension() {
		super(true);
		setName("Time");
		setPrefix("time");
		try {
			setURI(new URI("http://www.xes-standard.org/time.xesext"));
		} catch (Exception e) {
			System.err.println(e.getMessage());
		}

		XesAttribute attribute = new XesStringAttributeImpl();
		attribute.setKey(TIME);
		addEventAttribute(attribute);
		addAlias(attribute, "EN", "Timestamp");
		addAlias(attribute, "DE", "Zeitstempel");
		addAlias(attribute, "FR", "Horodateur");
		addAlias(attribute, "ES", "Timestamp");
		addAlias(attribute, "PT", "Timestamp");
	}

	/**
	 * @return The single instance of this extension.
	 */
	public static XesTimeExtension instance() {
		return singleton;
	}

	private XesDateTimeAttribute setDateTime(XesComponent component, String key, Date value) {
		XesDateTimeAttribute attribute = new XesDateTimeAttributeImpl();
		attribute.setKey(key);
		attribute.setValue(value);
		component.addAttribute(attribute);
		return attribute;
	}
	
	/**
	 * Returns the timestamp of the given event, that is, the value of the
	 * attribute with key "time:timestamp".
	 * 
	 * @param event
	 *            The given event.
	 * @return The timestamp of the given event.
	 */
	public Date getTimestamp(XesEvent event) {
		return event.getDateTime(TIME);
	}

	/**
	 * Sets the timestamp for the given event, that is, the value of the
	 * attribute with key "time:timestamp".
	 * 
	 * @param event
	 *            The given event.
	 * @param value
	 *            The timestamp to set.
	 * @return The old timestamp set.
	 */
	public XesDateTimeAttribute setTimestamp(XesEvent event, Date value) {
		return setDateTime(event, TIME, value);
	}
}
