package org.xesstandard.factory;

import org.xesstandard.model.XesClassifier;
import org.xesstandard.model.XesEvent;
import org.xesstandard.model.XesExtension;
import org.xesstandard.model.XesGlobal;
import org.xesstandard.model.XesLog;
import org.xesstandard.model.XesTrace;
import org.xesstandard.model.XesValues;
import org.xesstandard.model.attributes.XesBooleanAttribute;
import org.xesstandard.model.attributes.XesDateTimeAttribute;
import org.xesstandard.model.attributes.XesIdAttribute;
import org.xesstandard.model.attributes.XesIntegerNumberAttribute;
import org.xesstandard.model.attributes.XesListAttribute;
import org.xesstandard.model.attributes.XesRealNumberAttribute;
import org.xesstandard.model.attributes.XesStringAttribute;

public interface XesFactory {

	/**
	 * @return A fresh XES log. Version is set to <null>, features to empty list. 
	 */
	public XesLog createLog();

	/**
	 * @return A fresh XES extension. Name, prefix, and uri are set to <null>.
	 */
	public XesExtension createExtension();

	/**
	 * @return A fresh XES global.  Used by the XES parser, not in the model.
	 */
	public XesGlobal createGlobal();

	/**
	 * @return A fresh XES classifier. Name is set to <null>, keys to empty list.
	 */
	public XesClassifier createClassifier();

	/**
	 * @return A fresh XES trace. 
	 */
	public XesTrace createTrace();

	/**
	 * @return A fresh XES event. 
	 */
	public XesEvent createEvent();

	/**
	 * @return A fresh XES string attribute. Key and value are set to <null>.
	 */
	public XesStringAttribute createStringAttribute();

	/**
	 * @return A fresh XES date attribute. Key and value are set to <null>.
	 */
	public XesDateTimeAttribute createDateTimeAttribute();

	/**
	 * @return A fresh XES integer number attribute. Key and value are set to <null>.
	 */
	public XesIntegerNumberAttribute createIntegerNumberAttribute();

	/**
	 * @return A fresh XES real number attribute. Key and value are set to <null>.
	 */
	public XesRealNumberAttribute createRealNumberAttribute();

	/**
	 * @return A fresh XES boolean attribute. Key and value are set to <null>.
	 */
	public XesBooleanAttribute createBooleanAttribute();

	/**
	 * @return A fresh XES id attribute. Key and value are set to <null>.
	 */
	public XesIdAttribute createIdAttribute();

	/**
	 * @return A fresh XES list attribute. Key is set to null.
	 */
	public XesListAttribute createListAttribute();

	/**
	 * @return A fresh XES values. Used by the XES parser, not in the model.
	 */
	public XesValues createValues();
	
}
