package org.xesstandard.model;

import java.net.URI;
import java.util.List;

/**
 * XES Extension. See Clause 5.5.
 * 
 * @author H.M.W. Verbeek
 *
 */
public interface XesExtension {

	/**
	 * Sets the name for the extension.
	 * @param name The name to set. 
	 */
	public void setName(String name);
	/**
	 * @return The name set for the extension.
	 */
	public String getName();
	
	/**
	 * Sets the prefix for the extension.
	 * @param prefix The prefix to set. 
	 */
	public void setPrefix(String prefix);
	/**
	 * @return The prefix set for the extension.
	 */
	public String getPrefix();
	
	/**
	 * Sets the URI for the extension.
	 * @param uri The URI set for the extension. 
	 */
	public void setURI(URI uri);
	/**
	 * @return The URI set for the extension.
	 */
	public URI getURI();
	
	/**
	 * Adds a log attribute to the extension.
	 * @param attribute The log attribute to add.
	 */
	public void addLogAttribute(XesAttribute attribute);
	/**
	 * @return The log attributes set for (or added to) the extension.
	 */
	public List<XesAttribute> getLogAttributes();
	
	/**
	 * Adds a trace attribute to the extension.
	 * @param attribute The trace attribute to add.
	 */
	public void addTraceAttribute(XesAttribute attribute);
	/**
	 * @return The trace attributes set for (or added to) the extension.
	 */
	public List<XesAttribute> getTraceAttributes();
	
	/**
	 * Adds an event attribute to the extension.
	 * @param attribute The event attribute to add.
	 */
	public void addEventAttribute(XesAttribute attribute);
	/**
	 * @return The event attributes set for (or added to) the extension.
	 */
	public List<XesAttribute> getEventAttributes();
	
	/**
	 * Adds a meta attribute to the extension.
	 * @param attribute The meta attribute to add.
	 */
	public void addMetaAttribute(XesAttribute attribute);
	/**
	 * @return The meta attributes set for (or added to) the extension.
	 */
	public List<XesAttribute> getMetaAttributes();
	
	/**
	 * Returns whether this extension supports the given log attribute key.
	 * @param key The given attribute key.
	 * @return Whether this extension supports the given log attribute key.
	 */
	public boolean hasLogAttribute(String key);
	
	/**
	 * Returns whether this extension supports the given trace attribute key.
	 * @param key The given attribute key.
	 * @return Whether this extension supports the given trace attribute key.
	 */
	public boolean hasTraceAttribute(String key);
	
	/**
	 * Returns whether this extension supports the given event attribute key.
	 * @param key The given attribute key.
	 * @return Whether this extension supports the given event attribute key.
	 */
	public boolean hasEventAttribute(String key);
	
	/**
	 * Returns whether this extension supports the given meta attribute key.
	 * @param key The given attribute key.
	 * @return Whether this extension supports the given meta attribute key.
	 */
	public boolean hasMetaAttribute(String key);
	
	public void addAlias(XesAttribute attribute, String mapping, String alias);
	
	public String getAlias(XesAttribute attribute, String mapping);
}
