package org.xesstandard.model;

import java.util.List;

/**
 * XES Log. See Clause 5.1.
 * 
 * @author H.M.W. Verbeek
 *
 */
public interface XesLog extends XesComponent {

	/*
	 * Attributes
	 */
	
	/**
	 * Sets the version for the log.
	 * @param version The version to set. Should correspond to a decimal (like "99.99"). 
	 */
	public void setVersion(String version);
	/**
	 * @return The version set for the log.
	 */
	public String getVersion();
	
	/**
	 * Adds a feature to the log.
	 * @param feature The feature to add. 
	 */
	public void addFeature(String feature);
	/**
	 * @return The list of features set for (or added to) the log.
	 * The first feature added will be the first in the list etc.
	 */
	public List<String> getFeatures();
	
	/*
	 * Extensions.
	 */
	
	/**
	 * Adds an extension to the log. 
	 * @param extension The extension to add. 
	 * The first extension added will be the first in the list etc.
	 */
	public void addExtension(XesExtension extension);
	/**
	 * @return The list of extensions set for (or added to) the log.
	 * The first extension added will be the first in the list etc.
	 */
	public List<XesExtension> getExtensions();
	/**
	 * Returns the extension with that has the given prefix set.
	 * @param prefix The given prefix.
	 * @return The extension that has this prefix set. Returns <null> if no such extension exists.
	 */
	public XesExtension getExtension(String prefix);
	
	/*
	 * Global (trace, event) attributes.
	 */
	
	/**
	 * Adds an attribute as a global trace attribute to the log.
	 * @param attribute The attribute to add as a global trace attribute.
	 */
	public void addGlobalTraceAttribute(XesAttribute attribute);
	/**
	 * @return Returns the list of global trace attributes set for (or added to) the log.
	 * The first trace attribute added will be the first in the list etc.
	 */
	public List<XesAttribute> getGlobalTraceAttributes();
	
	/**
	 * Adds an attribute as a global event attribute to the log.
	 * @param attribute The attribute to add as a global event attribute.
	 */
	public void addGlobalEventAttribute(XesAttribute attribute);
	/**
	 * @return Returns the list of global event attributes set for (or added to) the log.
	 * The first event attribute added will be the first in the list etc.
	 */
	public List<XesAttribute> getGlobalEventAttributes();
	
	/*
	 * Classifiers.
	 */
	
	/**
	 * Adds a classifier as trace classifier to the log.
	 * @param classifier The classifier to add as trace classifier.
	 */
	public void addTraceClassifier(XesClassifier classifier);
	/**
	 *  @return The list of trace classifiers set for (or added to) the log.
	 * The first trace classifier added will be the first in the list etc.
	 */
	public List<XesClassifier> getTraceClassifiers();
	
	/**
	 * Adds a classifier as event classifier to the log.
	 * @param classifier The classifier to add as event classifier.
	 */
	public void addEventClassifier(XesClassifier classifier);
	/**
	 *  @return The list of event classifiers set for (or added to) the log.
	 * The first event classifier added will be the first in the list etc.
	 */
	public List<XesClassifier> getEventClassifiers();
	
	/*
	 * Traces.
	 */
	
	/**
	 * Adds a trace to the log.
	 * @param trace The trace to add.
	 */
	public void addTrace(XesTrace trace);
	/**
	 *  @return The list of traces set for (or added to) the log.
	 * The first trace added will be the first in the list etc.
	 */
	public List<XesTrace> getTraces();
	
	/*
	 * Events.
	 */
	
	/**
	 * Adds an event to the log.
	 * @param event The event to add.
	 */
	public void addEvent(XesEvent event);
	/**
	 *  @return The list of events set for (or added to) the log.
	 * The first event added will be the first in the list etc.
	 */
	public List<XesEvent> getEvents();
	
}
