package org.xesstandard.model.impl;

import java.net.URI;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.xesstandard.model.XesAttribute;
import org.xesstandard.model.XesExtension;

public class XesExtensionImpl implements XesExtension {

	/*
	 * Name of the extension.
	 */
	private String name = null;
	
	/*
	 * Prefix of the extension.
	 */
	private String prefix = null;
	
	/*
	 * URI of the extension.
	 */
	private URI uri = null;
	
	private boolean isStandard = false;;
	
	public XesExtensionImpl(boolean isStandard) {
		this.isStandard = isStandard;
	}
	
	public XesExtensionImpl() {
		this(false);
	}
	
	/*
	 * Log, trace, event, and meta attributes of the extension.
	 */
	private List<XesAttribute> logAttributes = new ArrayList<XesAttribute>();
	private List<XesAttribute> traceAttributes = new ArrayList<XesAttribute>();
	private List<XesAttribute> eventAttributes = new ArrayList<XesAttribute>();
	private List<XesAttribute> metaAttributes = new ArrayList<XesAttribute>();
	
	private Map<XesAttribute, Map<String, String>> aliases = new HashMap<XesAttribute, Map<String, String>>();
	
	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#setName(java.lang.String)
	 */
	public void setName(String name) {
		this.name = name;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#getName()
	 */
	public String getName() {
		return name;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#setPrefix(java.lang.String)
	 */
	public void setPrefix(String prefix) {
		this.prefix = prefix;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#getPrefix()
	 */
	public String getPrefix() {
		return prefix;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#setURI(java.net.URI)
	 */
	public void setURI(URI uri) {
		this.uri = uri;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#getURI()
	 */
	public URI getURI() {
		return uri;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#addLogAttribute(org.xesstandard.model.XesAttribute)
	 */
	public void addLogAttribute(XesAttribute attribute) {
		logAttributes.add(attribute);
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#getLogAttributes()
	 */
	public List<XesAttribute> getLogAttributes() {
		return logAttributes;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#addTraceAttribute(org.xesstandard.model.XesAttribute)
	 */
	public void addTraceAttribute(XesAttribute attribute) {
		traceAttributes.add(attribute);
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#getTraceAttributes()
	 */
	public List<XesAttribute> getTraceAttributes() {
		return traceAttributes;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#addEventAttribute(org.xesstandard.model.XesAttribute)
	 */
	public void addEventAttribute(XesAttribute attribute) {
		eventAttributes.add(attribute);
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#getEventAttributes()
	 */
	public List<XesAttribute> getEventAttributes() {
		return eventAttributes;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#addMetaAttribute(org.xesstandard.model.XesAttribute)
	 */
	public void addMetaAttribute(XesAttribute attribute) {
		metaAttributes.add(attribute);
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#getMetaAttributes()
	 */
	public List<XesAttribute> getMetaAttributes() {
		return metaAttributes;
	}

	public String toString() {
		return name;
	}
	
	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#hasLogAttribute(java.lang.String)
	 */
	public boolean hasLogAttribute(String key) {
		return (key != null && hasAttribute(getLogAttributes(), key));
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#hasTraceAttribute(java.lang.String)
	 */
	public boolean hasTraceAttribute(String key) {
		return (key != null && hasAttribute(getTraceAttributes(), key));
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#hasEventAttribute(java.lang.String)
	 */
	public boolean hasEventAttribute(String key) {
		return (key != null && hasAttribute(getEventAttributes(), key));
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesExtension#hasMetaAttribute(java.lang.String)
	 */
	public boolean hasMetaAttribute(String key) {
		return (key != null && hasAttribute(getMetaAttributes(), key));
	}

	/*
	 * Checks the known attributes for this key.
	 */
	protected boolean hasAttribute(List<XesAttribute> attributes, String key) {
		for (XesAttribute attribute : attributes) {
			if (key.equals(attribute.getKey())) {
				return true;
			}
		}
		return false;
	}

	public void addAlias(XesAttribute attribute, String mapping, String alias) {
		Map<String, String> aliasMap = aliases.get(attribute);
		if (aliasMap == null) {
			aliasMap = new HashMap<String, String>();
			aliases.put(attribute,  aliasMap);
		}
		aliasMap.put(mapping,  alias);
		aliases.put(attribute, aliasMap);
	}

	public String getAlias(XesAttribute attribute, String mapping) {
		Map<String, String> aliasMap = aliases.get(attribute);
		if (aliasMap != null) {
			return aliasMap.get(mapping);
		}
		return null;
	}

}
