package org.xesstandard.xml;

import java.io.BufferedInputStream;
import java.io.File;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;

import javax.xml.parsers.SAXParserFactory;

import org.xesstandard.model.XesLog;

public abstract class XesAbstractXmlParser implements XesXmlParser {

	private XesXmlIssueLevel level;
	private List<XesXmlIssue> issues;

	public XesAbstractXmlParser(XesXmlIssueLevel level) {
		this.level = level;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.xesstandard.xml.XesXmlParser#canParse(java.io.File)
	 */
	public boolean canParse(File file) {
		String filename = file.getName();
		return filename.toLowerCase().endsWith(".xes");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.xesstandard.xml.XesXmlParser#parse(java.io.InputStream)
	 */
	public XesLog parse(InputStream is) {
		try {
			BufferedInputStream bis = new BufferedInputStream(is);
			// set up a specialized SAX2 handler to fill the container
			XesXmlHandler handler = new XesXmlHandler(level);
			// set up SAX parser and parse provided log file into the container
			SAXParserFactory parserFactory = SAXParserFactory.newInstance();
			parserFactory.setNamespaceAware(false);
			// Parse the XES log.
			parserFactory.newSAXParser().parse(bis, handler);
			bis.close();
			// Get any issues raised while parsing the XES log.
			issues = handler.getIssues();
			if (getErrors().isEmpty()) {
				// No issues correspond to errors. Return parsed log.
				return handler.getLog();
			}
		} catch (Exception e) {
		}
		// Some issues correspond to errors. Return <null> to indicate failure.
		return null;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.xesstandard.xml.XesXmlParser#getErrors()
	 */
	public List<XesXmlIssue> getErrors() {
		List<XesXmlIssue> errors = new ArrayList<XesXmlIssue>();
		for (XesXmlIssue issue : issues) {
			if (issue.isError(level)) {
				errors.add(issue);
			}
		}
		return errors;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.xesstandard.xml.XesXmlParser#getWarnings()
	 */
	public List<XesXmlIssue> getWarnings() {
		List<XesXmlIssue> warnings = new ArrayList<XesXmlIssue>();
		for (XesXmlIssue issue : issues) {
			if (!issue.isError(level)) {
				warnings.add(issue);
			}
		}
		return warnings;
	}

}
