package org.xesstandard.xml;

import java.io.File;
import java.io.InputStream;
import java.util.List;

import org.xesstandard.model.XesLog;

public interface XesXmlParser {

	/**
	 * @return The name of the parser.
	 */
	public String getName();
	
	/**
	 * @return A description of the parser.
	 */
	public String getDescription();
	
	/**
	 * @return The name of the author of the parser.
	 */
	public String getAuthor();
	
	/**
	 * Whether the parser can pare the given file.
	 * @param file The given file.
	 * @return Whether the parser can pare the given file.
	 */
	public boolean canParse(File file);
	
	/**
	 * Parses the given input for a XES log.
	 * @param input The given input
	 * @return The XES log parsed from the input, <null> if failure.
	 */
	public XesLog parse(InputStream  input);
	
	/**
	 * @return The list of errors detected while parsing the input.
	 * The parser should return <null> if any errors are detected.
	 */
	public List<XesXmlIssue> getErrors();
	
	/**
	 * @return The list of warnings detected while parsing the input.
	 */
	public List<XesXmlIssue> getWarnings();
	
}
