package org.xesstandard.xml;

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;

import org.xesstandard.model.XesLog;

public class XesXmlParserStrictlyConforming extends XesAbstractXmlParser {

	/**
	 * Strictly conforming parser. Accepts files that strictly conform to the XES specification.
	 * Return <null> if the file does not strictly conform.
	 */
	public XesXmlParserStrictlyConforming() {
		super(XesXmlIssueLevel.STRICTLYCONFORMING);
	}
	
	public String getName() {
		return "IEEE XES XML (Strictly Conforming)";
	}
	
	public String getDescription() {
		return "Reads a strictly conforming IEEE XES log from a plain XML serialization";
	}
	public String getAuthor() {
		return "Eric Verbeek";
	}
	
	public XesLog parse(File file) throws Exception {
		if (canParse(file)) {
			InputStream is = new FileInputStream(file);
			return parse(is);
		} else {
			throw new IllegalArgumentException("Parser cannot handle this file!");
		}
	}
}
