package org.xesstandard.xml.issues;

import org.xesstandard.model.XesAttribute;
import org.xesstandard.model.XesClassifier;
import org.xesstandard.model.XesEvent;
import org.xesstandard.model.XesExtension;
import org.xesstandard.model.XesGlobal;
import org.xesstandard.model.XesLog;
import org.xesstandard.model.XesTrace;
import org.xesstandard.xml.XesXmlIssueLevel;

public class XesXmlIssueAttributeRequired extends XesAbstractXmlIssue {

	/**
	 * Issue raised when an element lacks a required attribute.
	 */
	private Object object;
	private String attribute;
	String label;
	String clause;
	
	public XesXmlIssueAttributeRequired(XesLog log, String attribute) {
		super(XesXmlIssueLevel.CONFORMING);
		this.object = log;
		this.attribute = attribute;
		label = "Log";
		clause = "Clause 5.1.2";
	}
	
	public XesXmlIssueAttributeRequired(XesTrace trace, String attribute) {
		super(XesXmlIssueLevel.CONFORMING);
		this.object = trace;
		this.attribute = attribute;
		label = "Trace";
		clause = "Clause 5.2.2";
	}
	
	public XesXmlIssueAttributeRequired(XesEvent event, String attribute) {
		super(XesXmlIssueLevel.CONFORMING);
		this.object = event;
		this.attribute = attribute;
		label = "Event";
		clause = "Clause 5.3.2";
	}
	
	public XesXmlIssueAttributeRequired(XesAttribute parentAttribute, String attribute) {
		super(XesXmlIssueLevel.CONFORMING);
		this.object = parentAttribute;
		this.attribute = attribute;
		label = "Attribute";
		clause = "Clause 5.4.3 and Clause 5.4.4";
	}
	
	public XesXmlIssueAttributeRequired(XesExtension extension, String attribute) {
		super(XesXmlIssueLevel.CONFORMING);
		this.object = extension;
		this.attribute = attribute;
		label = "Extension";
		clause = "Clause 5.5.2";
	}
	
	public XesXmlIssueAttributeRequired(XesGlobal global, String attribute) {
		super(XesXmlIssueLevel.CONFORMING);
		this.object = global;
		this.attribute = attribute;
		label = "Global";
		clause = "Clause 5.6.2";
	}
	
	public XesXmlIssueAttributeRequired(XesClassifier classifier, String attribute) {
		super(XesXmlIssueLevel.CONFORMING);
		this.object = classifier;
		this.attribute = attribute;
		label = "Classifier";
		clause = "5.7.2";
	}
	
	public String toString() {
		return super.toString() + label + " must have attribute " + attribute + " (see " + clause + ").";
	}
}
